==> activity-center-api-0.9.5.1-zbq-20190318.081832-5-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/finance/FinanceConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.finance;

import java.io.Serializable;
import java.util.Date;

public class FinanceConfigDto implements Serializable {

    private static final long serialVersionUID = 896974156460978909L;

    private Long id;

    private Long appId;

    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Integer budget;

    // 冻结的预算，单位分
    private Integer frozenBudget;

    // 提现门槛单位分
    private Integer withdrawThreshold;

    // 预警门槛百分比
    private Double alarmThreshold;

    // 临界门槛百分比
    private Double limitThreshold;

    // 针对每个周期的系数JSON
    private String coefficientJson;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Integer getBudget() {
        return budget;
    }

    public void setBudget(Integer budget) {
        this.budget = budget;
    }

    public Integer getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Integer frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Integer getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Integer withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public Double getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(Double alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public Double getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(Double limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public String getCoefficientJson() {
        return coefficientJson;
    }

    public void setCoefficientJson(String coefficientJson) {
        this.coefficientJson = coefficientJson;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-0.9.5.9-zbq-20190415.093501-7-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/finance/FinanceConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.finance;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FinanceConfigDto implements Serializable {

    private static final long serialVersionUID = 896974156460978909L;

    private Long id;

    private Long appId;

    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Long budget;

    // 冻结的预算，单位分
    private Long frozenBudget;

    /*总预算*/
    private Long totalBudget;

    // 提现门槛单位分
    private Long withdrawThreshold;

    // 预警门槛百分比
    private Double alarmThreshold;

    // 临界门槛百分比
    private Double limitThreshold;

    // 针对每个周期的系数JSON
    private String coefficientJson;

    private List<CoefficientDto> coefficients;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Long getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Long frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public Double getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(Double alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public Double getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(Double limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public String getCoefficientJson() {
        return coefficientJson;
    }

    public void setCoefficientJson(String coefficientJson) {
        this.coefficientJson = coefficientJson;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getTotalBudget() {
        return totalBudget;
    }

    public void setTotalBudget(Long totalBudget) {
        this.totalBudget = totalBudget;
    }

    public List<CoefficientDto> getCoefficients() {
        return coefficients;
    }

    public void setCoefficients(List<CoefficientDto> coefficients) {
        this.coefficients = coefficients;
    }
}
